import {request} from '@/utils/request'

/**
 * 扫码请求
 * @param ocId   单位ID
 * @param qrCode 二维码
 * @returns
 */
export function getByQr(ocId, qrCode) {
  return request({
    url: `/qr/request/${ocId}/${qrCode}`,
    method: 'GET'
  })
}
/**
 * WX登陆
 * @param jsCode 二维码
 * @returns
 */
export function wxLogin(jsCode) {
  return request({
    url: `/wx/login/${jsCode}`,
    method: 'GET'
  })
}
/**
 * 扫码请求checklist清单
 * @param ocId   单位ID
 * @param checklistId 清单ID
 * @returns
 */
export function getChecklistByQr(ocId,targetId,checklistId) {
  return request({
    url: `/qr/request/checklist/${ocId}/${targetId}/${checklistId}`,
    method: 'GET'
  })
}

/**
 * 保存checklist记录
 * @param data
 *  
    ocId
	wxId
	checklistId
	targetId:
	targetType:
	remark:
	cardNo:
	pointRecordList [  checklistId, itemId, pointId, score  ]
 * @returns
 */

export function createChecklistRecord(data) {
  return request({
    url: `/qr/checklist/record`,
    method: 'POST',
    headers: {
      'Content-Type': 'application/json;charset=UTF-8'
    },
    data
  })
}
/**
 * 解密WX用户数据
 * @param jsCode 二维码
 * @returns
 */
export function wxDecryptUserInfo(data) {
  return request({
    url: `/wx/userInfo/decrypt`,
    method: 'POST',
    data
  })
}