import {
	request
} from '@/utils/request'

/**
 * 列表查询Checklist Item
 * @param data
 * @returns
 */
export function getChecklistItemByList(data) {
  return request({
    url: '/checklist/item',
    method: 'GET',
    params: data
  })
}

/**
 * 基于Checklist Id查询Checklist Item List
 * @param checklistId 清单ID
 * @returns
 */
export function getChecklistItemViewByList(checklistId) {
  return request({
    url: '/checklist/item/${checklistId}',
    method: 'GET'
  })
}

/**
 * 基于ID查询
 * @param checklistId  清单ID
 * @param itemId 分类项ID
 * @returns
 */
export function getChecklistItemById(checklistId, itemId) {
  return request({
    url: `/checklist/item/${checklistId}/${itemId}`,
    method: 'GET'
  })
}

/**
 * 添加Checklist Item
 * @param data
 * @returns
 */
export function createChecklistItem(data) {
  return request({
    url: `/checklist/item/add`,
    method: 'POST',
    data
  })
}

/**
 * 更新Checklist Item
 * @param data
 * @returns
 */
export function updateChecklistItem(data) {
  return request({
    url: `/checklist/item/update`,
    method: 'PUT',
    data
  })
}

/**
 * 删除Checklist Item
 * @param checklistId  清单ID
 * @param itemId 分类项ID
 * @returns
 */
export function deleteChecklistItemById(checklistId, itemId) {
  return request({
    url: `/checklist/item/${checklistId}/${itemId}`,
    method: 'DELETE'
  })
}

